==> ZenTaoPMS.biz7.0.php7.0.zip: zentaopms/extension/biz/user/ext/model/class/bizext.class.php <==
<?php //0067d
if(!extension_loaded('ionCube Loader')){$__oc=strtolower(substr(php_uname(),0,3));$__ln='ioncube_loader_'.$__oc.'_'.substr(phpversion(),0,3).(($__oc=='win')?'.dll':'.so');if(function_exists('dl')){@dl($__ln);}if(function_exists('_il_exec')){return _il_exec();}$__ln='/ioncube/'.$__ln;$__oid=$__id=realpath(ini_get('extension_dir'));$__here=dirname(__FILE__);if(strlen($__id)>1&&$__id[1]==':'){$__id=str_replace('\\','/',substr($__id,2));$__here=str_replace('\\','/',substr($__here,2));}$__rd=str_repeat('/..',substr_count($__id,'/')).$__here.'/';$__i=strlen($__rd);while($__i--){if($__rd[$__i]=='/'){$__lp=substr($__rd,0,$__i).$__ln;if(file_exists($__oid.$__lp)){$__ln=$__lp;break;}}}if(function_exists('dl')){@dl($__ln);}}else{die('The file '.__FILE__." is corrupted.\n");}if(function_exists('_il_exec')){return _il_exec();}
$documentRoot = isset($_SERVER['SCRIPT_FILENAME']) ? dirname($_SERVER['SCRIPT_FILENAME']) : $_SERVER['DOCUMENT_ROOT'];
$link = is_file($documentRoot . '/loader-wizard.php') ? '/loader-wizard.php' : 'http://www.ioncube.com/lw/';
echo "<html>
  <head>
    <meta http-equiv='content-type' content='text/html; charset=utf-8' />
    <title>error</title>
  </head>
  <body>
    <h2 style='color:red;text-align:center'>未安装 ioncube loader</h2>
    <p>您需要安装ioncube loader才能使用该功能， 使用<a href='$link'>ioncube loader安装向导</a>。</p>
    <br /><br /><br />
    <h2 style='color:red;text-align:center'>Ioncube loader doesn't installed.</h2>
    <p>You haven't installed ioncube loader extension, please visit <a href='$link'>the install wizard</a> to install it.</p>
  </body>
</html>";
exit;

?>
HR+cPywg63AMSk45snwD4PcnKF0bOTeWXvjTp+YFm3QBquDdSyp+GSSR7y32rc+IcIlpewEGuvkZ
jMLtsLhKfGN2pmEHG5OfC8UdX2PzMzM5qX2X2u+md4Pm+EFZ7JuUKruRCfi8MjHDaq7r0mS7ysr0
Q8X0Sv8WVOD1EYckas7lP/0KEdirQC6b3bR8M+iec4o2ioqZpPdhM0Ryy4VCd13K6gxtgggPvTOX
hRgjVDq8i5CkD3E97VJqJlsybH666RqlSB8LeOdYXUEbJk8Vp8gS9FsA01QDIZ9UNX8xoAcedbsq
ofqzBeJHYMePccKidwPIVlWER74uJx9Gut6VmOT/LTh+DFWfe4sLR0yg6J4KuSRMr3cz5u1+8up4
tyuRcoJFGgpw6N3E0B5HaVIEWh7/nNrDUBnigF0gAEV8+b5wTEcmtMS+sd4a7fF/eqXsBKNFTM/7
jqBiVQBynIZF1A4eNCVAOGCOMDO8e00rvT0cumYycvo0/bzC53TZRFylOsTe34QZ7Ghsv5AQRE5A
vpxlCcsr4Cl8oczCfF8hgxdeAaWOxpypNRLnB+1LVk/RsLUZg8jQJfUFZaPOCtsGwvyqFop7r19+
35u4Q/Slixcx0NlooAZgOb8AKHrtA9xVCVQk6CiLBYsNHvm7La/FLhsF3mWaeEVDY5IPDE7uKKQ8
sU3NpxOKnja9DLgqAx68jMOphO7wXaHI2oG17vLKlvvpawkxANAS60==

==> ZenTaoPMS.biz7.3.php7.2_7.4.zip: zentaopms/extension/biz/user/ext/model/class/bizext.class.php <==
<?php //0067d
if(!extension_loaded('ionCube Loader')){$__oc=strtolower(substr(php_uname(),0,3));$__ln='ioncube_loader_'.$__oc.'_'.substr(phpversion(),0,3).(($__oc=='win')?'.dll':'.so');if(function_exists('dl')){@dl($__ln);}if(function_exists('_il_exec')){return _il_exec();}$__ln='/ioncube/'.$__ln;$__oid=$__id=realpath(ini_get('extension_dir'));$__here=dirname(__FILE__);if(strlen($__id)>1&&$__id[1]==':'){$__id=str_replace('\\','/',substr($__id,2));$__here=str_replace('\\','/',substr($__here,2));}$__rd=str_repeat('/..',substr_count($__id,'/')).$__here.'/';$__i=strlen($__rd);while($__i--){if($__rd[$__i]=='/'){$__lp=substr($__rd,0,$__i).$__ln;if(file_exists($__oid.$__lp)){$__ln=$__lp;break;}}}if(function_exists('dl')){@dl($__ln);}}else{die('The file '.__FILE__." is corrupted.\n");}if(function_exists('_il_exec')){return _il_exec();}
$documentRoot = isset($_SERVER['SCRIPT_FILENAME']) ? dirname($_SERVER['SCRIPT_FILENAME']) : $_SERVER['DOCUMENT_ROOT'];
$link = is_file($documentRoot . '/loader-wizard.php') ? '/loader-wizard.php' : 'http://www.ioncube.com/lw/';
echo "<html>
  <head>
    <meta http-equiv='content-type' content='text/html; charset=utf-8' />
    <title>error</title>
  </head>
  <body>
    <h2 style='color:red;text-align:center'>未安装 ioncube loader</h2>
    <p>您需要安装ioncube loader才能使用该功能， 使用<a href='$link'>ioncube loader安装向导</a>。</p>
    <br /><br /><br />
    <h2 style='color:red;text-align:center'>Ioncube loader doesn't installed.</h2>
    <p>You haven't installed ioncube loader extension, please visit <a href='$link'>the install wizard</a> to install it.</p>
  </body>
</html>";
exit;

?>
HR+cPnOZTikb24lj19VZwBQrb7J9vOnhJOrAmZgpxJRFRBpRGuXx7pV+6K55QiaC01GH4grIl6ql
7OKfuqe1yQJ1+SZiKSgrXhUVSRkxJHot8Y4THuUBTBzu0LRqnzXogA3qP7qMZv3xKkHZ+FuW3bxH
W8zaSxZd0yJo3wu+Ol2E5xB9Eq2YMptQgKTsWPnsQ6QI6EYzrdCeHigcpzgPVTizUDIZNKcVkd/4
xQGWDN+qpd1oSxUNVRp7FxWq4Hs07E/FezJzsohvFc14/RBOGOcrtGeKSZkBISZXZNSa1c2MLUJo
JmcDxW76AKLvpKGZNLcp+j1IsXXbEVlDfpAIvy+UAH5INhf2JQ2fk0Z3Ni5AlYC5x3LJ2YzNLFfK
xqTdCdMhy2GcHSatxoKKoPILSgG9+fJeu8Eh5i6KBKznxFuakSU7yKeMJME5by02yjmpj9G/Yw4x
LVAwThjbHOKn1uObBeHj6lK8TTuoA7Ae1BmfswuxyJBJLTagfcAf8/kkD3xKzWvA4X+c5ARcSeY3
HDnw2PEic6WXBjywhczPjmSji8Tpg+ZRCMMD82u76HcFBrvOi0EhJ4nakhsWekQDgdVPghD2NitY
Ee0/a39YA/+0nKCDp4ZudEDgEBoBXntxT5NPds5q/bDGnzPLNjLa3u0n6goskVnC1jor71xBySJf
0BaHcAOz+me6LfuK21Pw2vU4PUTEVQ76/dqLd0pn5n/az8oNkuLm0Z4=
